tw2.wysihtml5
=============

WYSIHTML5 widget for ToscaWidgets2.

WYSIHTML5 is a lightweight HTML5 rich text editing plugin developed
by xing. You can find it's source here: https://github.com/xing/wysihtml5

Example: http://xing.github.com/wysihtml5/

Use it like any other ToscaWidgets2 widget library.

While not strictly required, it is advised that you use this
widget together with the tw2.bootstrap.forms module to provide a
nice looking interface.

